Fix numerous typos in comments
authorJonathan Wakely <jwakely@redhat.com>
Mon, 3 Apr 2017 22:30:56 +0000 (23:30 +0100)
committerJonathan Wakely <redi@gcc.gnu.org>
Mon, 3 Apr 2017 22:30:56 +0000 (23:30 +0100)
gcc:

* alias.c (base_alias_check): Fix typo in comment.
* cgraph.h (class ipa_polymorphic_call_context): Likewise.
* cgraphunit.c (symbol_table::compile): Likewise.
* collect2.c (maybe_run_lto_and_relink): Likewise.
* config/arm/arm.c (arm_thumb1_mi_thunk): Likewise.
* config/avr/avr-arch.h (avr_arch_info_t): Likewise.
* config/avr/avr.c (avr_map_op_t): Likewise.
* config/cr16/cr16.h (DATA_ALIGNMENT): Likewise.
* config/epiphany/epiphany.c (TARGET_ARG_PARTIAL_BYTES): Likewise.
* config/epiphany/epiphany.md (movcc): Likewise.
* config/i386/i386.c (legitimize_pe_coff_extern_decl): Likewise.
* config/m68k/m68k.c (struct _sched_ib, m68k_sched_variable_issue):
Likewise.
* config/mips/mips.c (mips_save_restore_reg): Likewise.
* config/rx/rx.c (rx_is_restricted_memory_address): Likewise.
* config/s390/s390.c (Z10_EARLYLOAD_DISTANCE): Likewise.
* config/sh/sh.c (sh_rtx_costs): Likewise.
* fold-const.c (fold_truth_andor): Likewise.
* genautomata.c (collapse_flag): Likewise.
* gengtype.h (struct type::u::s): Likewise.
* gensupport.c (has_subst_attribute, add_mnemonic_string): Likewise.
* input.c (FORMAT_AMOUNT): Likewise.
* ipa-cp.c (class ipcp_lattice, agg_replacements_to_vector)
(known_aggs_to_agg_replacement_list): Likewise.
* ipa-inline-analysis.c: Likewise.
* ipa-inline.h (estimate_edge_time, estimate_edge_hints): Likewise.
* ipa-polymorphic-call.c
(ipa_polymorphic_call_context::restrict_to_inner_class): Likewise.
* loop-unroll.c (analyze_insn_to_expand_var): Likewise.
* lra.c (lra_optional_reload_pseudos, lra_subreg_reload_pseudos):
Likewise.
* modulo-sched.c (apply_reg_moves): Likewise.
* omp-expand.c (build_omp_regions_1): Likewise.
* trans-mem.c (struct tm_wrapper_hasher): Likewise.
* tree-ssa-loop-ivopts.c (may_eliminate_iv): Likewise.
* tree-ssa-loop-niter.c (maybe_lower_iteration_bound): Likewise.
* tree-vect-data-refs.c (vect_enhance_data_refs_alignment): Likewise.
* value-prof.c: Likewise.
* var-tracking.c (val_reset): Likewise.

gcc/ada:

* doc/gnat_ugn/gnat_and_program_execution.rst: Fix typo.
* g-socket.adb (To_Host_Entry): Fix typo in comment.
* gnat_ugn.texi: Fix typo.
* raise.c (_gnat_builtin_longjmp): Fix capitalization in comment.
* s-stposu.adb (Allocate_Any_Controlled): Fix typo in comment.
* sem_ch3.adb (Build_Derived_Record_Type): Likewise.
* sem_util.adb (Mark_Coextensions): Likewise.
* sem_util.ads (Available_Full_View_Of_Component): Likewise.

gcc/c:

* c-array-notation.c: Fix typo in comment.

gcc/c-family:

* c-warn.c (do_warn_double_promotion): Fix typo in comment.

gcc/cp:

        * class.c (update_vtable_entry_for_fn): Fix typo in comment.
* decl2.c (one_static_initialization_or_destruction): Likewise.
* name-lookup.c (store_bindings): Likewise.
* parser.c (make_call_declarator): Likewise.
* pt.c (check_explicit_specialization): Likewise.

gcc/testsuite:

* g++.old-deja/g++.benjamin/scope02.C: Fix typo in comment.
* gcc.dg/20031012-1.c: Likewise.
* gcc.dg/ipa/ipcp-1.c: Likewise.
* gcc.dg/torture/matrix-3.c: Likewise.
* gcc.target/powerpc/ppc-spe.c: Likewise.
* gcc.target/rx/zero-width-bitfield.c: Likewise.

libcpp:

* include/line-map.h (LINEMAPS_MACRO_MAPS): Fix typo in comment.
* lex.c (search_line_fast): Likewise.
* pch.h (cpp_valid_state): Likewise.

libdecnumber:

* decCommon.c (decFloatFromPackedChecked): Fix typo in comment.
* decNumber.c (decNumberPower, decMultiplyOp): Likewise.

libgcc:

* config/c6x/pr-support.c (__gnu_unwind_execute): Fix typo in comment.

libitm:

* libitm_i.h (sutrct gtm_thread): Fix typo in comment.

From-SVN: r246664

73 files changed:
gcc/ChangeLog
gcc/ada/ChangeLog
gcc/ada/doc/gnat_ugn/gnat_and_program_execution.rst
gcc/ada/g-socket.adb
gcc/ada/gnat_ugn.texi
gcc/ada/raise.c
gcc/ada/s-stposu.adb
gcc/ada/sem_ch3.adb
gcc/ada/sem_util.adb
gcc/ada/sem_util.ads
gcc/alias.c
gcc/c-family/ChangeLog
gcc/c-family/c-warn.c
gcc/c/ChangeLog
gcc/c/c-array-notation.c
gcc/cgraph.h
gcc/cgraphunit.c
gcc/collect2.c
gcc/config/arm/arm.c
gcc/config/avr/avr-arch.h
gcc/config/avr/avr.c
gcc/config/cr16/cr16.h
gcc/config/epiphany/epiphany.c
gcc/config/epiphany/epiphany.md
gcc/config/i386/i386.c
gcc/config/m68k/m68k.c
gcc/config/mips/mips.c
gcc/config/rx/rx.c
gcc/config/s390/s390.c
gcc/config/sh/sh.c
gcc/cp/ChangeLog
gcc/cp/class.c
gcc/cp/decl2.c
gcc/cp/name-lookup.c
gcc/cp/parser.c
gcc/cp/pt.c
gcc/fold-const.c
gcc/genautomata.c
gcc/gengtype.h
gcc/gensupport.c
gcc/input.c
gcc/ipa-cp.c
gcc/ipa-inline-analysis.c
gcc/ipa-inline.h
gcc/ipa-polymorphic-call.c
gcc/loop-unroll.c
gcc/lra.c
gcc/modulo-sched.c
gcc/omp-expand.c
gcc/testsuite/ChangeLog
gcc/testsuite/g++.old-deja/g++.benjamin/scope02.C
gcc/testsuite/gcc.dg/20031012-1.c
gcc/testsuite/gcc.dg/ipa/ipcp-1.c
gcc/testsuite/gcc.dg/torture/matrix-3.c
gcc/testsuite/gcc.target/powerpc/ppc-spe.c
gcc/testsuite/gcc.target/rx/zero-width-bitfield.c
gcc/trans-mem.c
gcc/tree-ssa-loop-ivopts.c
gcc/tree-ssa-loop-niter.c
gcc/tree-vect-data-refs.c
gcc/value-prof.c
gcc/var-tracking.c
libcpp/ChangeLog
libcpp/include/line-map.h
libcpp/lex.c
libcpp/pch.c
libdecnumber/ChangeLog
libdecnumber/decCommon.c
libdecnumber/decNumber.c
libgcc/ChangeLog
libgcc/config/c6x/pr-support.c
libitm/ChangeLog
libitm/libitm_i.h

index 30daa0d087546ca62f491a115c92d6683d6344ee..a92c3a5b5e074098ce0458b38ef69bb7b40fc4e7 100644 (file)
@@ -1,3 +1,45 @@
+2017-04-03  Jonathan Wakely  <jwakely@redhat.com>
+
+       * alias.c (base_alias_check): Fix typo in comment.
+       * cgraph.h (class ipa_polymorphic_call_context): Likewise.
+       * cgraphunit.c (symbol_table::compile): Likewise.
+       * collect2.c (maybe_run_lto_and_relink): Likewise.
+       * config/arm/arm.c (arm_thumb1_mi_thunk): Likewise.
+       * config/avr/avr-arch.h (avr_arch_info_t): Likewise.
+       * config/avr/avr.c (avr_map_op_t): Likewise.
+       * config/cr16/cr16.h (DATA_ALIGNMENT): Likewise.
+       * config/epiphany/epiphany.c (TARGET_ARG_PARTIAL_BYTES): Likewise.
+       * config/epiphany/epiphany.md (movcc): Likewise.
+       * config/i386/i386.c (legitimize_pe_coff_extern_decl): Likewise.
+       * config/m68k/m68k.c (struct _sched_ib, m68k_sched_variable_issue):
+       Likewise.
+       * config/mips/mips.c (mips_save_restore_reg): Likewise.
+       * config/rx/rx.c (rx_is_restricted_memory_address): Likewise.
+       * config/s390/s390.c (Z10_EARLYLOAD_DISTANCE): Likewise.
+       * config/sh/sh.c (sh_rtx_costs): Likewise.
+       * fold-const.c (fold_truth_andor): Likewise.
+       * genautomata.c (collapse_flag): Likewise.
+       * gengtype.h (struct type::u::s): Likewise.
+       * gensupport.c (has_subst_attribute, add_mnemonic_string): Likewise.
+       * input.c (FORMAT_AMOUNT): Likewise.
+       * ipa-cp.c (class ipcp_lattice, agg_replacements_to_vector)
+       (known_aggs_to_agg_replacement_list): Likewise.
+       * ipa-inline-analysis.c: Likewise.
+       * ipa-inline.h (estimate_edge_time, estimate_edge_hints): Likewise.
+       * ipa-polymorphic-call.c
+       (ipa_polymorphic_call_context::restrict_to_inner_class): Likewise.
+       * loop-unroll.c (analyze_insn_to_expand_var): Likewise.
+       * lra.c (lra_optional_reload_pseudos, lra_subreg_reload_pseudos):
+       Likewise.
+       * modulo-sched.c (apply_reg_moves): Likewise.
+       * omp-expand.c (build_omp_regions_1): Likewise.
+       * trans-mem.c (struct tm_wrapper_hasher): Likewise.
+       * tree-ssa-loop-ivopts.c (may_eliminate_iv): Likewise.
+       * tree-ssa-loop-niter.c (maybe_lower_iteration_bound): Likewise.
+       * tree-vect-data-refs.c (vect_enhance_data_refs_alignment): Likewise.
+       * value-prof.c: Likewise.
+       * var-tracking.c (val_reset): Likewise.
+
 2017-04-03  Richard Biener  <rguenther@suse.de>
 
        PR tree-optimization/80275
index 3efce33d08f4481078b254b85714d1968a57ca03..127a181431f3bc7286e98889ddf7fa6561f75f7c 100644 (file)
@@ -1,3 +1,14 @@
+2017-04-03  Jonathan Wakely  <jwakely@redhat.com>
+
+       * doc/gnat_ugn/gnat_and_program_execution.rst: Fix typo.
+       * g-socket.adb (To_Host_Entry): Fix typo in comment.
+       * gnat_ugn.texi: Fix typo.
+       * raise.c (_gnat_builtin_longjmp): Fix capitalization in comment.
+       * s-stposu.adb (Allocate_Any_Controlled): Fix typo in comment.
+       * sem_ch3.adb (Build_Derived_Record_Type): Likewise.
+       * sem_util.adb (Mark_Coextensions): Likewise.
+       * sem_util.ads (Available_Full_View_Of_Component): Likewise.
+
 2017-03-28  Andreas Schwab  <schwab@suse.de>
 
        PR ada/80117
index b090236b48c09abb1b2cdd929a6b1774f8bf31b1..37c077e92d1a2ee8f28f474a37a7dc9a3e5cbe5f 100644 (file)
@@ -3091,7 +3091,7 @@ The three modes are:
 
 Note that these modes apply only to the evaluation of predefined
 arithmetic, membership, and comparison operators for signed integer
-aritmetic.
+arithmetic.
 
 For fixed-point arithmetic, checks can be suppressed. But if checks
 are enabled
index a8b718a511abb6e117a4b3f7190081c8295bc935..07931af601c2594cfc79ea0aefc59f4b7c71376b 100644 (file)
@@ -2541,7 +2541,7 @@ package body GNAT.Sockets is
 
                --  Hostent_H_Addr (E, <index>) may return an address that is
                --  not correctly aligned for In_Addr, so we need to use
-               --  an intermediate copy operation on a type with an alignemnt
+               --  an intermediate copy operation on a type with an alignment
                --  of 1 to recover the value.
 
                subtype Addr_Buf_T is C.char_array (1 .. Addr'Size / 8);
index 421419f5bfa90eb3f92830c260ea21d5dbeee4f7..1916d1efc571a7dde5cd40a027ecceeaa3683c22 100644 (file)
@@ -22168,7 +22168,7 @@ but overflow is impossible.
 
 Note that these modes apply only to the evaluation of predefined
 arithmetic, membership, and comparison operators for signed integer
-aritmetic.
+arithmetic.
 
 For fixed-point arithmetic, checks can be suppressed. But if checks
 are enabled
index a0c012167773f708d0a1862b2158f59a5b9d7301..a61723d10e40e21ac0034f2cc438391930ed5e6c 100644 (file)
@@ -50,7 +50,7 @@ extern "C" {
 /*  Wrapper to builtin_longjmp.  This is for the compiler eh only, as the sjlj
     runtime library interfaces directly to the intrinsic.  We can't yet do
     this for the compiler itself, because this capability relies on changes
-    made in april 2008 and we need to preserve the possibility to bootstrap
+    made in April 2008 and we need to preserve the possibility to bootstrap
     with an older base version.  */
 
 #if defined (IN_GCC) && !defined (IN_RTS)
index 6c98e6b505138ab611f7549fea70f38928db3050..d017ce3686e94e79838d8a9455c78e75c9a8958b 100644 (file)
@@ -221,7 +221,7 @@ package body System.Storage_Pools.Subpools is
          pragma Assert
            (Fin_Address /= null, "primitive Finalize_Address not available");
 
-         --  The size must acount for the hidden header preceding the object.
+         --  The size must account for the hidden header preceding the object.
          --  Account for possible padding space before the header due to a
          --  larger alignment.
 
index 1f774c00a62ece2d3284ff60460d45e25acad08d..de3a49e29103a3c7f23bae32a335e7376a23efde 100644 (file)
@@ -8706,7 +8706,7 @@ package body Sem_Ch3 is
 
                --  However, if the record contains an array constrained by
                --  the discriminant but with some different bound, the compiler
-               --  attemps to create a smaller range for the discriminant type.
+               --  attempts to create a smaller range for the discriminant type.
                --  (See exp_ch3.Adjust_Discriminants). In this case, where
                --  the discriminant type is a scalar type, the check must use
                --  the original discriminant type in the parent declaration.
index 1d78642e659fb2314bf71256cfb4624a0cf7bed7..93d8bd58d81b624dbd84a79d6465cc990b9f790b 100644 (file)
@@ -16131,7 +16131,7 @@ package body Sem_Util is
                                                N_Allocator,
                                                N_Qualified_Expression);
 
-      --  An alloctor that appears within the initialization expression of an
+      --  An allocator that appears within the initialization expression of an
       --  object declaration is considered a potentially dynamic coextension
       --  when the initialization expression is an allocator or a qualified
       --  expression.
index 42d51a5f848b996650de72c2d8e917f63bf7cd54..f9ab8135481428a7faa281662ce71da7062d5bbe 100644 (file)
@@ -154,10 +154,10 @@ package Sem_Util is
 
    function Available_Full_View_Of_Component (T : Entity_Id) return Boolean;
    --  If at the point of declaration an array type has a private or limited
-   --  component, several array operations are not avaiable on the type, and
+   --  component, several array operations are not available on the type, and
    --  the array type is flagged accordingly. If in the immediate scope of
    --  the array type the component becomes non-private or non-limited, these
-   --  operations become avaiable. This can happen if the scopes of both types
+   --  operations become available. This can happen if the scopes of both types
    --  are open, and the scope of the array is not outside the scope of the
    --  component.
 
index 93c136f27d022688f16728d23c69696f7add9c1f..cc31ee0e261724813c851012f86688b4a19006d6 100644 (file)
@@ -2157,7 +2157,7 @@ base_alias_check (rtx x, rtx x_base, rtx y, rtx y_base,
   /* The base addresses are different expressions.  If they are not accessed
      via AND, there is no conflict.  We can bring knowledge of object
      alignment into play here.  For example, on alpha, "char a, b;" can
-     alias one another, though "char a; long b;" cannot.  AND addesses may
+     alias one another, though "char a; long b;" cannot.  AND addresses may
      implicitly alias surrounding objects; i.e. unaligned access in DImode
      via AND address can alias all surrounding object types except those
      with aligment 8 or higher.  */
index 0d5a16f66091e4b374565447a2c4b6666134d45c..594aa05a5522651d0e72b7b959c4ae75f5cd90bc 100644 (file)
@@ -1,3 +1,7 @@
+2017-04-03  Jonathan Wakely  <jwakely@redhat.com>
+
+       * c-warn.c (do_warn_double_promotion): Fix typo in comment.
+
 2017-03-31  Jakub Jelinek  <jakub@redhat.com>
 
        PR c++/79572
index cdfa10c792d13d5ae0d91933590bcb65cca2de7c..45dd583111ef68481b3782f5796276af206333c8 100644 (file)
@@ -1850,7 +1850,7 @@ warn_for_sign_compare (location_t location,
    the warning message.  It must have two %T specifiers for the type
    that was converted (generally "float") and the type to which it was
    converted (generally "double), respectively.  LOC is the location
-   to which the awrning should refer.  */
+   to which the warning should refer.  */
 
 void
 do_warn_double_promotion (tree result_type, tree type1, tree type2,
index b64d9cfe90519da97ea058ce2afa8a21112eed0f..ec1922162329d17624753f6af2663d478b2da8f2 100644 (file)
@@ -1,3 +1,7 @@
+2017-04-03  Jonathan Wakely  <jwakely@redhat.com>
+
+       * c-array-notation.c: Fix typo in comment.
+
 2017-03-29  Marek Polacek  <polacek@redhat.com>
 
        PR c/79730
index 4c6651ea29c31aaeaa4868a063c903752ee2e733..e430f5c681bfdd8e6e3389767d3ca14058c5dc11 100644 (file)
@@ -26,7 +26,7 @@
    An array notation expression has 4 major components:
    1. The array name
    2. Start Index
-   3. Number of elements we need to acess (we call it length)
+   3. Number of elements we need to access (we call it length)
    4. Stride
 
    For example, A[0:5:2], implies that we are accessing A[0], A[2], A[4],
index 62cebd9e55add25afbef4209d6be5dab91c77d7d..77aa8803a0adeda634bfefe287f71d91b9fd213c 100644 (file)
@@ -1511,7 +1511,7 @@ public:
      Return true if resulting context is valid.
 
      When CONSIDER_PLACEMENT_NEW is false, reject contexts that may be made
-     valid only via alocation of new polymorphic type inside by means
+     valid only via allocation of new polymorphic type inside by means
      of placement new.
 
      When CONSIDER_BASES is false, only look for actual fields, not base types
index 8635e3bd0e91cb9346784ee3fd2cddd6e4fb5a9b..4a949ca9d73dc5a6703b267361b7ca9a0a11b97d 100644 (file)
@@ -2497,7 +2497,7 @@ symbol_table::compile (void)
   bitmap_obstack_release (NULL);
   mark_functions_to_output ();
 
-  /* When weakref support is missing, we autmatically translate all
+  /* When weakref support is missing, we automatically translate all
      references to NODE to references to its ultimate alias target.
      The renaming mechanizm uses flag IDENTIFIER_TRANSPARENT_ALIAS and
      TREE_CHAIN.
index b109f73517ad5ccbdfc152c32f0104bdedab3062..ddbd2be8bf8945d026341ef1d660d591cced36eb 100644 (file)
@@ -761,7 +761,7 @@ maybe_run_lto_and_relink (char **lto_ld_argv, char **object_lst,
       do_wait (prog, pex);
       pex = NULL;
 
-      /* Compute memory needed for new LD arguments.  At most number of original arguemtns
+      /* Compute memory needed for new LD arguments.  At most number of original arguments
         plus number of partitions.  */
       for (lto_ld_argv_size = 0; lto_ld_argv[lto_ld_argv_size]; lto_ld_argv_size++)
        ;
index b24143e32e2f100000f3b150f7ed0df4fabb3cc8..bc1e607c42c9ba12a473e4df8ef51f788e041f62 100644 (file)
@@ -26228,7 +26228,7 @@ arm_thumb1_mi_thunk (FILE *file, tree, HOST_WIDE_INT delta,
     {
       int labelno = thunk_label++;
       ASM_GENERATE_INTERNAL_LABEL (label, "LTHUMBFUNC", labelno);
-      /* Thunks are entered in arm mode when avaiable.  */
+      /* Thunks are entered in arm mode when available.  */
       if (TARGET_THUMB1_ONLY)
        {
          /* push r3 so we can use it as a temporary.  */
index 9c426882e1efb8e6cf5708f639890ba6b70c1595..94637356a1ed6269c6553ccdabb9a38cde6ffd09 100644 (file)
@@ -169,7 +169,7 @@ typedef struct
   /* Architecture ID.  */
   enum avr_arch_id arch_id;
 
-  /* textinfo source to describe the archtiecture.  */
+  /* textinfo source to describe the architecture.  */
   const char *texinfo;
 } avr_arch_info_t;
 
index cde63f10e633d2530bda59812386e2f0ace504c0..7f5a22b8edfe2c2ca165665a93cd3b440153aeb2 100644 (file)
@@ -13335,7 +13335,7 @@ typedef struct
   /* G^-1, the inverse of G (*, arg) */
   unsigned ginv;
 
-  /* The cost of appplying G (*, arg) */
+  /* The cost of applying G (*, arg) */
   int cost;
 
   /* The composition F o G^-1 (*, arg) for some function F */
index 7f8796ccb7f085b307c887602a7c5ac01ae88ae6..e2a678ea1ee23c5f3b4ab50c508fe273c0dce8b0 100644 (file)
@@ -114,7 +114,7 @@ while (0)
      && ((ALIGN) < BITS_PER_WORD))               \
      ? (BITS_PER_WORD) : (ALIGN))
 
-/* In CR16 strings are word-aligne; strcpy from constants will be faster.  */
+/* In CR16 strings are word-aligned; strcpy from constants will be faster.  */
 #define CONSTANT_ALIGNMENT(CONSTANT, ALIGN)                            \
   (((TREE_CODE (CONSTANT) == STRING_CST) && ((ALIGN) < BITS_PER_WORD)) \
      ? (BITS_PER_WORD) : (ALIGN))
index 41864f2c502d51939b891c535121b3f5f85a4565..b9ec0f40d12ab4ac78091535d6945c146f105d9a 100644 (file)
@@ -95,7 +95,7 @@ static rtx_insn *frame_insn (rtx);
 #define TARGET_SETUP_INCOMING_VARARGS epiphany_setup_incoming_varargs
 
 /* Using the simplistic varags handling forces us to do partial reg/stack
-   argument passing for types with larger size (> 4 bytes) than alignemnt.  */
+   argument passing for types with larger size (> 4 bytes) than alignment.  */
 #define TARGET_ARG_PARTIAL_BYTES epiphany_arg_partial_bytes
 
 #define TARGET_FUNCTION_OK_FOR_SIBCALL epiphany_function_ok_for_sibcall
index 595c53e9ddb731fc149fa1fdffe6854fd306b19e..90a59422e4351157a3c94edefbdf581d80c28d00 100644 (file)
   [(set_attr "type" "flow")])
 
 ; Floating point instructions require manipulating the control register.
-; Manipulating the control register needs aritmetic.
+; Manipulating the control register needs arithmetic.
 ; Arithmetic clobbers flags.
 ; The flags are in the status register, which also contains the alternate
 ; flag and the interrupt enable/disable bits.
index 6e27a09a7a9dd052aa790c09f54c0fce80e60134..80b8773649460d8e1fabfd7c79c27209edbca302 100644 (file)
@@ -16713,7 +16713,7 @@ get_dllimport_decl (tree decl, bool beimport)
   return to;
 }
 
-/* Expand SYMBOL into its corresponding far-addresse symbol.
+/* Expand SYMBOL into its corresponding far-address symbol.
    WANT_REG is true if we require the result be a register.  */
 
 static rtx
index a4c0b81bd97331d2b1de6c9e4c6afabb938e7e8f..c14ce86d8102b41a891ca45ff7f2e2dbaf6f2fc5 100644 (file)
@@ -6019,7 +6019,7 @@ struct _sched_ib
     /* Size of buffer in records.  */
     int n_insns;
 
-    /* Array to hold data on adjustements made to the size of the buffer.  */
+    /* Array to hold data on adjustments made to the size of the buffer.  */
     int *adjust;
 
     /* Index of the above array.  */
@@ -6081,7 +6081,7 @@ m68k_sched_variable_issue (FILE *sched_dump ATTRIBUTE_UNUSED,
          if (sched_ib.records.adjust_index == sched_ib.records.n_insns)
            sched_ib.records.adjust_index = 0;
 
-         /* Undo adjustement we did 7 instructions ago.  */
+         /* Undo adjustment we did 7 instructions ago.  */
          sched_ib.size
            += sched_ib.records.adjust[sched_ib.records.adjust_index];
 
index dadfcc431fe18ea6940792404fdcc812cba60c6c..42943e01908b5aee7cf6374bb64c90a6a9f7521e 100644 (file)
@@ -11414,7 +11414,7 @@ mips_save_restore_reg (machine_mode mode, int regno,
   fn (gen_rtx_REG (mode, regno), mem);
 }
 
-/* Call FN for each accumlator that is saved by the current function.
+/* Call FN for each accumulator that is saved by the current function.
    SP_OFFSET is the offset of the current stack pointer from the start
    of the frame.  */
 
index e6bb846156d66504d34851f8f3aa50f27e2c01d9..1e74f380bdb284c2ca664e711dc2359874f4dff5 100644 (file)
@@ -267,7 +267,7 @@ rx_is_legitimate_address (machine_mode mode, rtx x,
   return rx_small_data_operand (x);
 }
 
-/* Returns TRUE for simple memory addreses, ie ones
+/* Returns TRUE for simple memory addresses, ie ones
    that do not involve register indirect addressing
    or pre/post increment/decrement.  */
 
index 0b1a95f2dca0e10301d49aaa213f95fb375b7248..51b3d46924b88173cf69eeace98fe9d1ae39d933 100644 (file)
@@ -13968,7 +13968,7 @@ s390_fpload_toreg (rtx_insn *insn, unsigned int regno)
 }
 
 /* This value describes the distance to be avoided between an
-   aritmetic fp instruction and an fp load writing the same register.
+   arithmetic fp instruction and an fp load writing the same register.
    Z10_EARLYLOAD_DISTANCE - 1 as well as Z10_EARLYLOAD_DISTANCE + 1 is
    fine but the exact value has to be avoided. Otherwise the FP
    pipeline will throw an exception causing a major penalty.  */
index 5b84b15e7babfcd6e8594a0da96b8389ae3e6858..ff79b93adc263e02114c815ff3706ad57d5cad60 100644 (file)
@@ -3259,7 +3259,7 @@ sh_rtx_costs (rtx x, machine_mode mode ATTRIBUTE_UNUSED, int outer_code,
       return false;
 
     /* The cost of a sign or zero extend depends on whether the source is a
-       reg or a mem.  In case of a mem take the address into acount.  */
+       reg or a mem.  In case of a mem take the address into account.  */
     case SIGN_EXTEND:
       if (arith_reg_operand (XEXP (x, 0), GET_MODE (XEXP (x, 0))))
        {
index f3c668b870de1d7af9cbf16f169323620dc1b74c..01baeb810aba9e73ba235b9d43d7ff656246bd86 100644 (file)
@@ -1,3 +1,11 @@
+2017-04-03  Jonathan Wakely  <jwakely@redhat.com>
+
+       * class.c (update_vtable_entry_for_fn): Fix typo in comment.
+       * decl2.c (one_static_initialization_or_destruction): Likewise.
+       * name-lookup.c (store_bindings): Likewise.
+       * parser.c (make_call_declarator): Likewise.
+       * pt.c (check_explicit_specialization): Likewise.
+
 2017-04-03  Jason Merrill  <jason@redhat.com>
 
        PR sanitizer/79993 - ICE with VLA initialization from string
index 9e4b4c4fd326429d6699e6cce75da459aad26702..940cead072ec1f058ada641affa14bd29465769f 100644 (file)
@@ -2789,7 +2789,7 @@ update_vtable_entry_for_fn (tree t, tree binfo, tree fn, tree* virtuals,
      determined by which bases the function overrides, so we need to be
      sure that we're using a thunk for some overridden base; even if we
      know that the necessary this adjustment is zero, there may not be an
-     appropriate zero-this-adjusment thunk for us to use since thunks for
+     appropriate zero-this-adjustment thunk for us to use since thunks for
      overriding virtual bases always use the vcall offset.
 
      Furthermore, just choosing any base that overrides this function isn't
index b50fadf050db0e34616c420f6a715f8c0fc1e20f..9c351fda44d12c52d16ec999ab1a01922163d4c3 100644 (file)
@@ -3648,10 +3648,10 @@ one_static_initialization_or_destruction (tree decl, tree init, bool initp)
 
   /* Make sure temporary variables in the initialiser all have
      their DECL_CONTEXT() set to a value different from NULL_TREE.
-     This can happen when global variables initialisers are built.
+     This can happen when global variables initializers are built.
      In that case, the DECL_CONTEXT() of the global variables _AND_ of all 
      the temporary variables that might have been generated in the
-     accompagning initialisers is NULL_TREE, meaning the variables have been
+     accompanying initializers is NULL_TREE, meaning the variables have been
      declared in the global namespace.
      What we want to do here is to fix that and make sure the DECL_CONTEXT()
      of the temporaries are set to the current function decl.  */
index 4d7d3a1bad4c613ecd47862cb6801f17c6d6cebc..9dedad4e181b25e0c7c93d98ecc3b3adacac13fd 100644 (file)
@@ -6341,7 +6341,7 @@ store_bindings (tree names, vec<cxx_saved_binding, va_gc> **old_bindings)
       vec_safe_reserve_exact (*old_bindings, bindings_need_stored.length ());
       for (i = 0; bindings_need_stored.iterate (i, &id); ++i)
        {
-         /* We can appearantly have duplicates in NAMES.  */
+         /* We can apparently have duplicates in NAMES.  */
          if (store_binding_p (id))
            store_binding (id, old_bindings);
        }
index e93855fb69d728bc07beb97a4bedc933223260c8..e202ad9bf120cf6f36c5f34d69be7c10919c7031 100644 (file)
@@ -1584,7 +1584,7 @@ make_ptrmem_declarator (cp_cv_quals cv_qualifiers, tree class_type,
 }
 
 /* Make a declarator for the function given by TARGET, with the
-   indicated PARMS.  The CV_QUALIFIERS aply to the function, as in
+   indicated PARMS.  The CV_QUALIFIERS apply to the function, as in
    "const"-qualified member function.  The EXCEPTION_SPECIFICATION
    indicates what exceptions can be thrown.  */
 
index cbe80821b54ffa7a7a7f7f937564acedeb7c28c8..24b01e70ba6a1ca3e78694a734d510b86f4511b0 100644 (file)
@@ -2968,7 +2968,7 @@ check_explicit_specialization (tree declarator,
 
       /* Figure out what exactly is being specialized at this point.
         Note that for an explicit instantiation, even one for a
-        member function, we cannot tell apriori whether the
+        member function, we cannot tell a priori whether the
         instantiation is for a member template, or just a member
         function of a template class.  Even if a member template is
         being instantiated, the member template arguments may be
index 7c05e0fc01a4799660ae0949595c2a9ebd045b8b..d0f1c0685ca05aa514c63f6f3321da3743ae556e 100644 (file)
@@ -8072,7 +8072,7 @@ fold_truth_andor (location_t loc, enum tree_code code, tree type,
          return fold_build2_loc (loc, icode, type, TREE_OPERAND (arg0, 0),
                                  tem);
        }
-       /* Same as abouve but for (A AND[-IF] (B AND-IF C)) -> ((A AND B) AND-IF C),
+       /* Same as above but for (A AND[-IF] (B AND-IF C)) -> ((A AND B) AND-IF C),
           or (A OR[-IF] (B OR-IF C) -> ((A OR B) OR-IF C).  */
       else if (TREE_CODE (arg1) == icode
          && simple_operand_p_2 (arg0)
index adec86831447bdd5fd94d4acc12804b090ef386e..76dacbc39846fb1a3ed3cb9347fcda0f0a50f8e8 100644 (file)
@@ -248,7 +248,7 @@ static int ndfa_flag;
 
 /* When making an NDFA, produce additional transitions that collapse
    NDFA state into a deterministic one suitable for querying CPU units.
-   Provide avance-state transitions only for deterministic states.  */
+   Provide advance-state transitions only for deterministic states.  */
 static int collapse_flag;
 
 /* Do not make minimization of DFA (`-no-minimization').  */
index d57f45ccf0dcc4bfd107b87cef7b2ef800aec15c..61a799ff3a9e8875fe2ea5aea55d9a6bdae96bcd 100644 (file)
@@ -277,7 +277,7 @@ struct type {
     /* when TYPE_STRUCT or TYPE_UNION or TYPE_LANG_STRUCT, we have an
        aggregate type containing fields: */
     struct {
-      const char *tag;          /* the aggragate tag, if any.  */
+      const char *tag;          /* the aggregate tag, if any.  */
       struct fileloc line;      /* the source location.  */
       pair_p fields;            /* the linked list of fields.  */
       options_p opt;            /* the GTY options if any.  */
index 874e677fa0021c10061b3febeb1c3eeb1d492373..c79feb48ad15d619cf4e8fde2a65995a42b4ddf4 100644 (file)
@@ -679,7 +679,7 @@ change_subst_attribute (struct queue_elem *elem,
    represented by SUBST_ELEM and this attribute has value SUBST_TRUE.
    DEFINE_SUBST isn't applied to patterns without such attribute.  In other
    words, we suppose the default value of the attribute to be 'no' since it is
-   always generated automaticaly in read-rtl.c.  */
+   always generated automatically in read-rtl.c.  */
 static bool
 has_subst_attribute (struct queue_elem *elem, struct queue_elem *subst_elem)
 {
@@ -2259,7 +2259,7 @@ htab_eq_string (const void *s1, const void *s2)
 }
 
 /* Add mnemonic STR with length LEN to the mnemonic hash table
-   MNEMONIC_HTAB.  A trailing zero end character is appendend to STR
+   MNEMONIC_HTAB.  A trailing zero end character is appended to STR
    and a permanent heap copy of STR is created.  */
 
 static void
index 38deb62db216f9f5c52248525ee18e1f0c32c2fa..80718100d0c5fac5baf22d8518aebad0788f89f3 100644 (file)
@@ -885,7 +885,7 @@ make_location (location_t caret, location_t start, location_t finish)
 #define STAT_LABEL(x) ((x) < 10 * ONE_K ? ' ' : ((x) < 10 * ONE_M ? 'k' : 'M'))
 
 /* Display an integer amount as multiple of 1K or 1M (in base 2).
-   Display the correct unit (either k, M, or ' ') after the amout, as
+   Display the correct unit (either k, M, or ' ') after the amount, as
    well.  */
 #define FORMAT_AMOUNT(size) SCALE (size), STAT_LABEL (size)
 
index 16e7e2216ab96489a7985e0280cc637ff1954ea2..0b408149a88dd728329f23435fa03923fc0eaf2c 100644 (file)
@@ -193,7 +193,7 @@ public:
 };
 
 /* Lattice describing potential values of a formal parameter of a function, or
-   a part of an aggreagate.  TOP is represented by a lattice with zero values
+   a part of an aggregate.  TOP is represented by a lattice with zero values
    and with contains_variable and bottom flags cleared.  BOTTOM is represented
    by a lattice with the bottom flag set.  In that case, values and
    contains_variable flag should be disregarded.  */
@@ -4014,7 +4014,7 @@ intersect_with_plats (struct ipcp_param_lattices *plats,
     }
 }
 
-/* Copy agggregate replacement values of NODE (which is an IPA-CP clone) to the
+/* Copy aggregate replacement values of NODE (which is an IPA-CP clone) to the
    vector result while subtracting OFFSET from the individual value offsets.  */
 
 static vec<ipa_agg_jf_item>
@@ -4276,7 +4276,7 @@ find_aggregate_values_for_callers_subset (struct cgraph_node *node,
   return res;
 }
 
-/* Turn KNOWN_AGGS into a list of aggreate replacement values.  */
+/* Turn KNOWN_AGGS into a list of aggregate replacement values.  */
 
 static struct ipa_agg_replacement_value *
 known_aggs_to_agg_replacement_list (vec<ipa_agg_jump_function> known_aggs)
index 611faab570f67b83e88f890a9cdb7ec311a0726f..97338e19f3a681412205fc4ce32f111eeb211d11 100644 (file)
@@ -30,12 +30,12 @@ along with GCC; see the file COPYING3.  If not see
    For each call
      - call statement size and time
 
-   inlinie_summary datastructures store above information locally (i.e.
+   inline_summary data structures store above information locally (i.e.
    parameters of the function itself) and globally (i.e. parameters of
    the function created by applying all the inline decisions already
    present in the callgraph).
 
-   We provide accestor to the inline_summary datastructure and
+   We provide access to the inline_summary data structure and
    basic logic updating the parameters when inlining is performed. 
 
    The summaries are context sensitive.  Context means
@@ -43,7 +43,7 @@ along with GCC; see the file COPYING3.  If not see
      2) whether function is inlined into the call or not.
    It is easy to add more variants.  To represent function size and time
    that depends on context (i.e. it is known to be optimized away when
-   context is known either by inlining or from IP-CP and clonning),
+   context is known either by inlining or from IP-CP and cloning),
    we use predicates. Predicates are logical formulas in
    conjunctive-disjunctive form consisting of clauses. Clauses are bitmaps
    specifying what conditions must be true. Conditions are simple test
index 6bbb97f0404e3ee94a0077d1e76150949d6ef139..0010530ab2ee30cb1d914624c70103aff3253266 100644 (file)
@@ -309,7 +309,7 @@ estimate_edge_growth (struct cgraph_edge *edge)
          - inline_edge_summary (edge)->call_stmt_size);
 }
 
-/* Return estimated callee runtime increase after inlning
+/* Return estimated callee runtime increase after inlining
    EDGE.  */
 
 static inline int
@@ -323,7 +323,7 @@ estimate_edge_time (struct cgraph_edge *edge)
 }
 
 
-/* Return estimated callee runtime increase after inlning
+/* Return estimated callee runtime increase after inlining
    EDGE.  */
 
 static inline inline_hints
index e690d05158d1d8fd4326da1b5763a6632c7c6670..c8bab92b7bbc7430cf4a8d4a6fdb19b78d8b5475 100644 (file)
@@ -117,7 +117,7 @@ possible_placement_new (tree type, tree expected_type,
    Return true when lookup was sucesful.
 
    When CONSIDER_PLACEMENT_NEW is false, reject contexts that may be made
-   valid only via alocation of new polymorphic type inside by means
+   valid only via allocation of new polymorphic type inside by means
    of placement new.
 
    When CONSIDER_BASES is false, only look for actual fields, not base types
index 1a9cea1678dd750b00f3981de23d85472bcaa968..dd5bdc519b01ccafaecf21dccd0fb6c310f6d9a9 100644 (file)
@@ -1454,7 +1454,7 @@ analyze_insn_to_expand_var (struct loop *loop, rtx_insn *insn)
   if (debug_uses)
     /* Instead of resetting the debug insns, we could replace each
        debug use in the loop with the sum or product of all expanded
-       accummulators.  Since we'll only know of all expansions at the
+       accumulators.  Since we'll only know of all expansions at the
        end, we'd have to keep track of which vars_to_expand a debug
        insn in the loop references, take note of each copy of the
        debug insn during unrolling, and when it's all done, compute
index ed1f062d2ee51592938e330655e3a0c68dda4270..1230b25e7e12e6dcc41ac51a96e9d1522ec6d1f5 100644 (file)
--- a/gcc/lra.c
+++ b/gcc/lra.c
@@ -2267,13 +2267,13 @@ bitmap_head lra_inheritance_pseudos;
 /* Split regnos before the new spill pass.  */
 bitmap_head lra_split_regs;
 
-/* Reload pseudo regnos before the new assignmnet pass which still can
-   be spilled after the assinment pass as memory is also accepted in
+/* Reload pseudo regnos before the new assignment pass which still can
+   be spilled after the assignment pass as memory is also accepted in
    insns for the reload pseudos.  */
 bitmap_head lra_optional_reload_pseudos;
 
 /* Pseudo regnos used for subreg reloads before the new assignment
-   pass.  Such pseudos still can be spilled after the assinment
+   pass.  Such pseudos still can be spilled after the assignment
    pass.  */
 bitmap_head lra_subreg_reload_pseudos;
 
index 270adc5a2008bf9ea3579681d571f4aad1c3635f..720391f7cfed376b781cae9d7139ba1cadbf0983 100644 (file)
@@ -805,7 +805,7 @@ schedule_reg_moves (partial_schedule_ptr ps)
   return true;
 }
 
-/* Emit the moves associatied with PS.  Apply the substitutions
+/* Emit the moves associated with PS.  Apply the substitutions
    associated with them.  */
 static void
 apply_reg_moves (partial_schedule_ptr ps)
index ea951d609b0e1f6d0e30da05a8fae9d9962c489a..5c48b7867c20b0f768fea40ebbf30f0ff1687f0a 100644 (file)
@@ -7986,7 +7986,7 @@ build_omp_regions_1 (basic_block bb, struct omp_region *parent,
        }
       else if (code == GIMPLE_OMP_ATOMIC_STORE)
        {
-         /* GIMPLE_OMP_ATOMIC_STORE is analoguous to
+         /* GIMPLE_OMP_ATOMIC_STORE is analogous to
             GIMPLE_OMP_RETURN, but matches with
             GIMPLE_OMP_ATOMIC_LOAD.  */
          gcc_assert (parent);
index 2e0fce74b07335529126c3870b0443af205ec05a..4a05eba88b9950a5b15dc8a931668a9585b5b8ab 100644 (file)
@@ -1,3 +1,12 @@
+2017-04-03  Jonathan Wakely  <jwakely@redhat.com>
+
+       * g++.old-deja/g++.benjamin/scope02.C: Fix typo in comment.
+       * gcc.dg/20031012-1.c: Likewise.
+       * gcc.dg/ipa/ipcp-1.c: Likewise.
+       * gcc.dg/torture/matrix-3.c: Likewise.
+       * gcc.target/powerpc/ppc-spe.c: Likewise.
+       * gcc.target/rx/zero-width-bitfield.c: Likewise.
+
 2017-04-03  Peter Bergner  <bergner@vnet.ibm.com>
 
        PR target/80246
index 1ff541b88464a64f4c7efe2c8a9d2ea5c3f4bb91..1ac1233f37102ae5937c7f56e33c93258a9d36f5 100644 (file)
@@ -83,7 +83,7 @@ int main(void)
 
   // p 4 
 
-  // if the id-expr in a class member acess is a qualified-id, the
+  // if the id-expr in a class member access is a qualified-id, the
   // id-expression is looked up in both the context of the entire
   // postfix-expr and in the scope of the class of the object-expr. If
   // the name is found in both contexts, the id-expr shall refer to
index f83e1d3f57c33427124368b89ab76a2a895379ba..24a68d0e3da192e1a74a8f7ca66899df23564c5c 100644 (file)
@@ -1,6 +1,6 @@
 /* { dg-options "-Waddress" } */
 /* Origin: Andrew Morton <akpm@osdl.org> */
-/* Warn if a function addres of a non-weak function is used
+/* Warn if a function address of a non-weak function is used
    as a truth value.  */
 /* See thread starting at http://gcc.gnu.org/ml/gcc/2003-10/msg00414.html  */
 
index 9591c5e2ba10030c9302b4100193915a65f59eb3..952694d302bd192aafba5f55908a4e54af3b5c1c 100644 (file)
@@ -1,6 +1,6 @@
-/* Test that IPA-CP is able to figure out that poth parameters a are constant 7
+/* Test that IPA-CP is able to figure out that both parameters a are constant 7
    even though f and h recursively call each other and specialize them
-   accordinly.  */
+   accordingly.  */
 
 /* { dg-do compile } */
 /* { dg-options "-O3 -fipa-cp -fipa-cp-clone -fdump-ipa-cp -fno-early-inlining"  } */
index c646899a326756fddd8e85df71ee1cc3e6b55509..a2093abdf221a5511e0e6f9c5227ebcfc88a10fe 100644 (file)
@@ -11,7 +11,7 @@ int ***vel;
 void just_a_call (int *);
 
 /* The last dimension of VEL escapes because it was sent
-   as argumet to just_a_call(). (external function)
+   as argument to just_a_call(). (external function)
    Only the two external dimensions are flattened.
    Run with -c.  */
 
index b56439433407c10a86b6f1d473603fa0de67694c..5880e046c04d0605939c98b04c10812506cd0afd 100644 (file)
@@ -22,7 +22,7 @@ float fl;
 uint16_t u16;
 int16_t s16;
 
-/* These are the only documented/supported accesor functions for the
+/* These are the only documented/supported accessor functions for the
    SPE builtins.  */
 void
 test_api ()
index 26cf5a2b542e2be0992f9697f639f0855440f4a2..8e477ffff742b7590221079d37bec0b880756f1d 100644 (file)
@@ -1,7 +1,7 @@
 /* { dg-do run { xfail rx-*-* } } */
 /* { dg-skip-if "skipped until patch for generic zero=width bit-field handling is accepted" { rx-*-* } { "*" } { "" } } */
 /* { dg-options "-msim" } */
-/* Note: The -msim abiove is actually there to override the default
+/* Note: The -msim above is actually there to override the default
    options which do not allow the GCC extension of zero-width bitfields.  */
 
 extern void abort (void);
index 9f559722c39b1a2cc60c34ff9dbd0717bda6949a..4409bea94d1388239d36a66b3d385d4923bb6dc4 100644 (file)
@@ -456,7 +456,7 @@ build_tm_abort_call (location_t loc, bool is_outer)
                                             | (is_outer ? AR_OUTERABORT : 0)));
 }
 \f
-/* Map for aribtrary function replacement under TM, as created
+/* Map for arbitrary function replacement under TM, as created
    by the tm_wrap attribute.  */
 
 struct tm_wrapper_hasher : ggc_cache_ptr_hash<tree_map>
index 8dc658812f248178c45cd1b4e270401a7e2caead..72e3ff98a3e7a707a55d9bb70d0e727feb4e6778 100644 (file)
@@ -5543,7 +5543,7 @@ may_eliminate_iv (struct ivopts_data *data,
     return false;
 
   /* Sometimes, it is possible to handle the situation that the number of
-     iterations may be zero unless additional assumtions by using <
+     iterations may be zero unless additional assumptions by using <
      instead of != in the exit condition.
 
      TODO: we could also calculate the value MAY_BE_ZERO ? 0 : NITER and
index de206471edb236b691e8e94d5e08af98b9ef1ebf..e67cd93094636a252c035b54e4dedb8386d0203a 100644 (file)
@@ -3697,7 +3697,7 @@ maybe_lower_iteration_bound (struct loop *loop)
      TODO: Due to the way record_estimate choose estimates to store, the bounds
      will be always nb_iterations_upper_bound-1.  We can change this to record
      also statements not dominating the loop latch and update the walk bellow
-     to the shortest path algorthm.  */
+     to the shortest path algorithm.  */
   for (elt = loop->bounds; elt; elt = elt->next)
     {
       if (!elt->is_exit
index 3d1d7e7f918b98a045b17276369ab6d5519891a3..aa504b6a1c694f7d8a1ac5e767d04504a67f8725 100644 (file)
@@ -1550,7 +1550,7 @@ vect_enhance_data_refs_alignment (loop_vec_info loop_vinfo)
                  Hence, except for the immediate peeling amount, we also want
                  to try to add full vector size, while we don't exceed
                  vectorization factor.
-                 We do this automtically for cost model, since we calculate cost
+                 We do this automatically for cost model, since we calculate cost
                  for every peeling option.  */
               if (unlimited_cost_model (LOOP_VINFO_LOOP (loop_vinfo)))
                {
index 22dc2c9e257019d0d8b7dd0dc8b6d7382585f3c3..1ce0fda0ed2cdf1bbb39635566cd23c796380a0f 100644 (file)
@@ -100,7 +100,7 @@ along with GCC; see the file COPYING3.  If not see
    * The value profiling code could be used to record analysis results
      from non-profiling (e.g. VRP).
    * Adding new profilers should be simplified, starting with a cleanup
-     of what-happens-where andwith making gimple_find_values_to_profile
+     of what-happens-where and with making gimple_find_values_to_profile
      and gimple_value_profile_transformations table-driven, perhaps...
 */
 
index b30a0ebcc3a68fdd30cdb87eda62ddcd59bdddef..1b9f8ddea6ab4e0ffbc97ddbdc62890a66dfbc83 100644 (file)
@@ -2555,7 +2555,7 @@ val_reset (dataflow_set *set, decl_or_value dv)
     {
       decl_or_value cdv = dv_from_value (cval);
 
-      /* Keep the remaining values connected, accummulating links
+      /* Keep the remaining values connected, accumulating links
         in the canonical value.  */
       for (node = var->var_part[0].loc_chain; node; node = node->next)
        {
index 95200dacbda730948772b08ec22c29b46162e71c..63cd5a52a33458972598f8a5bdf3cecae981e565 100644 (file)
@@ -1,3 +1,9 @@
+2017-04-03  Jonathan Wakely  <jwakely@redhat.com>
+
+       * include/line-map.h (LINEMAPS_MACRO_MAPS): Fix typo in comment.
+       * lex.c (search_line_fast): Likewise.
+       * pch.h (cpp_valid_state): Likewise.
+
 2017-03-21  Andreas Schwab  <schwab@suse.de>
 
        * lex.c (search_line_fast) [__ARM_NEON && __ARM_64BIT_STATE]:
index ec56de396151e1edd946f536cc4d2df7c50a7a31..522e8bb17ebaad2b44f0dcfde3f5aa3ef09c9161 100644 (file)
@@ -908,7 +908,7 @@ LINEMAPS_LAST_ALLOCATED_ORDINARY_MAP (const line_maps *set)
 }
 
 /* Returns a pointer to the beginning of the region where macro maps
-   are allcoated.  */
+   are allocated.  */
 inline line_map_macro *
 LINEMAPS_MACRO_MAPS (const line_maps *set)
 {
index a431ac8e0526f6b564cdb39bab7de0f166e0d0fa..9edd2a6afdbcc286dd9536af2c7bede2c0eeebe1 100644 (file)
@@ -912,7 +912,7 @@ search_line_fast (const uchar *s, const uchar *end ATTRIBUTE_UNUSED)
 
 #else
 
-/* We only have one accellerated alternative.  Use a direct call so that
+/* We only have one accelerated alternative.  Use a direct call so that
    we encourage inlining.  */
 
 #define search_line_fast  search_line_acc_char
index f65346fbc811e5cdd0eda49368997f84044704e4..cad4b872cda6e38d4b20bcdeba2db3cc945eaced 100644 (file)
@@ -630,7 +630,7 @@ cpp_valid_state (cpp_reader *r, const char *name, int fd)
             attempting to use it without -g.  Restoring the PCH file
             is supposed to bring in this definition *and* enable the
             generation of call frame information, so that precompiled
-            definitions that take this macro into accout, to decide
+            definitions that take this macro into account, to decide
             what asm to emit, won't issue .cfi directives when the
             compiler doesn't.  */
          if (!(h->flags & NODE_USED)
index 287e373efc873d9a4cec475fdd869690b84f1db6..984c92d37c8ce916ed41017a995b35a685df10b0 100644 (file)
@@ -1,3 +1,8 @@
+2017-04-03  Jonathan Wakely  <jwakely@redhat.com>
+
+       * decCommon.c (decFloatFromPackedChecked): Fix typo in comment.
+       * decNumber.c (decNumberPower, decMultiplyOp): Likewise.
+
 2017-01-08  Jakub Jelinek  <jakub@redhat.com>
 
        PR bootstrap/79003
index e31aebf21141a8e3011a614a6a94fd168aa126da..86037e0fdbc940ab054c0c6015b5aa8aadf99195 100644 (file)
@@ -713,7 +713,7 @@ decFloat * decFloatFromPacked(decFloat *df, Int exp, const uByte *packed) {
 /*  returns df, which will be canonical or NULL if any of the        */
 /*    requirements are not met (if this case df is unchanged); that   */
 /*    is, the input data must be as returned by decFloatToPacked,     */
-/*    except that all six sign codes are acccepted.                  */
+/*    except that all six sign codes are accepted.                   */
 /*                                                                   */
 /* No status will be set.                                            */
 /* ------------------------------------------------------------------ */
index 9e163186b505475a3f5e1ea88ccba18ce1eff586..566abb0b0103c3e9a6387fe4bf45ddf2d7659f06 100644 (file)
@@ -2171,7 +2171,7 @@ decNumber * decNumberPower(decNumber *res, const decNumber *lhs,
       /* if a negative power the constant 1 is needed, and if not subset */
       /* invert the lhs now rather than inverting the result later */
       if (decNumberIsNegative(rhs)) {  /* was a **-n [hence digits>0] */
-       decNumber *inv=invbuff;         /* asssume use fixed buffer */
+       decNumber *inv=invbuff;         /* assume use fixed buffer */
        decNumberCopy(&dnOne, dac);     /* dnOne=1;  [needed now or later] */
        #if DECSUBSET
        if (set->extended) {            /* need to calculate 1/lhs */
@@ -5197,7 +5197,7 @@ static decNumber * decMultiplyOp(decNumber *res, const decNumber *lhs,
 /*    exp(-x) where x can be the tiniest number (Ntiny).             */
 /*                                                                   */
 /* 2. Normalizing x to be <=0.1 (instead of <=1) reduces loop        */
-/*    iterations by appoximately a third with additional (although    */
+/*    iterations by approximately a third with additional (although    */
 /*    diminishing) returns as the range is reduced to even smaller    */
 /*    fractions.  However, h (the power of 10 used to correct the     */
 /*    result at the end, see below) must be kept <=8 as otherwise     */
index ada1365e4e6de6c419a18ac0a47326646cb030da..87fea5bc8c8de5bfe636fea95b7323ebf5bbe1ff 100644 (file)
@@ -1,3 +1,7 @@
+2017-04-03  Jonathan Wakely  <jwakely@redhat.com>
+
+       * config/c6x/pr-support.c (__gnu_unwind_execute): Fix typo in comment.
+
 2017-03-27  Claudiu Zissulescu  <claziss@synopsys.com>
 
        * config/arc/ieee-754/divdf3.S (__divdf3): Use __ARCEM__.
index 6731850cf8e9bcdaf6a134540bb1a100929cc6c3..f1ab7ad2f7d68f336d6549e215e6452f9f5f6563 100644 (file)
@@ -449,7 +449,7 @@ __gnu_unwind_execute (_Unwind_Context * context, __gnu_unwind_state * uws)
 
       if ((op & 0xf0) == 0xe0)
        {
-         /* B3 = reg.  RETURN case alreadh handled above.  */
+         /* B3 = reg.  RETURN case already handled above.  */
          int regno = unwind_frame_regs[op & 0xf];
 
          _Unwind_VRS_Get (context, _UVRSC_CORE, regno, _UVRSD_UINT32, &reg);
index f930cf38797def8526c07e708be283780e218512..07ab1fc2629b9f0a5a349c4d5846b329722d86ed 100644 (file)
@@ -1,3 +1,7 @@
+2017-04-03  Jonathan Wakely  <jwakely@redhat.com>
+
+       * libitm_i.h (sutrct gtm_thread): Fix typo in comment.
+
 2017-01-21  Jakub Jelinek  <jakub@redhat.com>
 
        PR other/79046
index 6ea17d27de04792b94752c9596e4c0365f038bfa..b3633bbadcf14197774c3e68e00cce51d15c20d2 100644 (file)
@@ -258,7 +258,7 @@ struct gtm_thread
   atomic<gtm_word> shared_state;
 
   // The lock that provides access to serial mode.  Non-serialized
-  // transactions acquire read locks; a serialized transaction aquires
+  // transactions acquire read locks; a serialized transaction acquires
   // a write lock.
   // Accessed from assembly language, thus the "asm" specifier on
   // the name, avoiding complex name mangling.